/* Hey EMACS -*- linux-c -*- */
/* $Id: link_slv.c 3723 2007-08-25 06:14:48Z roms $ */

/*  libticables2 - link cable library, a part of the TiLP project
 *  Copyright (C) 1999-2005  Romain Lievin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/* TI-GRAPH LINK USB support */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifndef NO_CABLE_SLV

#if defined(__WIN32__) && !defined(__MINGW32__)
# define HAVE_LIBUSB
#endif

#ifdef HAVE_LIBUSB
# include "linux/link_slv.c"
#endif
#ifdef HAVE_LINUX_TICABLE_H
# include "linux/link_dev.c"
#endif

#endif
